This folder is to generate poison data in lc.py.

Step 1: 

Choose the dataset you want to poison, and run the following command to generate the poisoned training data:
    eg. 

```shell
python gen_poisoned_data.py --dataset {dataset_name}
```